@@ -2,9 +2,9 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2017 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
-#  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
+#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 """
 all Python Standard Library objects (currently: CH 1-15 @ 2.7)
 and some other common objects (i.e. numpy.ndarray)
@@ -216,7 +216,8 @@ if HAS_CTYPES:
     a['CSizeTType'] = ctypes.c_size_t()
     a['CLibraryLoaderType'] = ctypes.cdll
     a['StructureType'] = _Struct
-    a['BigEndianStructureType'] = ctypes.BigEndianStructure()
+    if not IS_PYPY:
+        a['BigEndianStructureType'] = ctypes.BigEndianStructure()
 #NOTE: also LittleEndianStructureType and UnionType... abstract classes
 #NOTE: remember for ctypesobj.contents creates a new python object
 #NOTE: ctypes.c_int._objects is memberdescriptor for object's __dict__
@@ -344,7 +345,8 @@ if HAS_ALL:
 a['ShelveType'] = shelve.Shelf({})
 # data compression and archiving (CH 12)
 if HAS_ALL:
-    a['BZ2FileType'] = bz2.BZ2File(os.devnull) #FIXME: fail >= 3.3
+    if (hex(sys.hexversion) < '0x2070ef0') or PY3:
+        a['BZ2FileType'] = bz2.BZ2File(os.devnull) #FIXME: fail >= 3.3, 2.7.14
     a['BZ2CompressorType'] = bz2.BZ2Compressor()
     a['BZ2DecompressorType'] = bz2.BZ2Decompressor()
 #a['ZipFileType'] = _zip = zipfile.ZipFile(os.devnull,'w') #FIXME: fail >= 3.2
